@@ -3,8 +3,11 @@
 #' @description
 #' This function is used to compare the distribution of discharges in the sample data set 
 #' and the discharges in the full daily data set.
-#' Note that discharge is plotted on a logarithmic axis. The data is logged before the statistics are performed
-#' to determine the output of the boxplot.
+#' Note that discharge is plotted on a logarithmic axis. The boxplot is created 
+#' using the log values but the scale is presented in the original units. An 
+#' ideal situation would show the two boxes roughly similar to each other or 
+#' the sample boxplot having median, upper quartile, and higher values being 
+#' slightly greater than in the boxplot of all days.
 #' 
 #' Data come from named list, which contains a Sample dataframe with the sample data, 
 #' a Daily dataframe with the daily flow data,
@@ -23,6 +26,9 @@
 #' @param tinyPlot logical variable, if TRUE plot is designed to be plotted small as part of a multi-plot figure, default is FALSE.
 #' @param customPar logical defaults to FALSE. If TRUE, par() should be set by user before calling this function 
 #' @param las numeric in {0,1,2,3}; the style of axis labels, see ?par
+#' @param usgsStyle logical option to use USGS style guidelines. Setting this option
+#' to TRUE does NOT guarantee USGS complience. It will only change automatically
+#' generated labels. 
 #' @param \dots arbitrary graphical parameters that will be passed to genericEGRETDotPlot function (see ?par for options)
 #' @keywords graphics water-quality statistics
 #' @seealso \code{\link[graphics]{boxplot}}
@@ -38,7 +44,8 @@
 #' boxQTwice(eList)
 boxQTwice<-function(eList, 
                     printTitle = TRUE, qUnit = 2, cex=0.8,cex.main=1.1,logScale=TRUE, 
-                    cex.axis=1.1, tcl=0.5, las=1, tinyPlot = FALSE, customPar=FALSE,...){
+                    cex.axis=1.1, tcl=0.5, las=1, 
+                    tinyPlot = FALSE, usgsStyle=FALSE, customPar=FALSE,...){
   
   localINFO <- getInfo(eList)
   localSample <- getSample(eList)
@@ -84,9 +91,9 @@ boxQTwice<-function(eList,
     if (!customPar) par(mar=c(4,5,1,0.1),tcl=tcl,cex.lab=cex.axis)
     groupNames<-c("Sampled","All")
   } else {
-    yLabel <- qUnit@qUnitExpress
+    yLabel <- ifelse(usgsStyle, qUnit@unitUSGS, qUnit@qUnitExpress)
     if (!customPar) par(mar=c(5,6,4,2)+0.1,tcl=tcl,cex.lab=cex.axis)
-    groupNames<-c("Sampled Days","All Days")
+    groupNames<-c("Sampled","All")
   }
     
 #   numYTicks <- length(yTicks)
