@@ -12,8 +12,8 @@
 #' a Daily dataframe with the daily flow data,
 #' and an INFO dataframe with metadata. 
 #'
-#' @param startYear numeric specifying the starting date (expressed as decimal years, for example 1989.0) for the plot
-#' @param endYear numeric specifiying the ending date for the plot 
+#' @param yearStart numeric specifying the starting date (expressed as decimal years, for example 1989.0) for the plot
+#' @param yearEnd numeric specifiying the ending date for the plot 
 #' @param eList named list with at least the Daily, Sample, and INFO dataframes
 #' @param tinyPlot logical variable, if TRUE plot is designed to be short and wide, default is FALSE.
 #' @param concMax number specifying the maximum value to be used on the vertical axis, default is NA (which allows it to be set automatically by the data)
@@ -25,7 +25,8 @@
 #' (for example, adjusting margins with par(mar=c(5,5,5,5))). If customPar FALSE, EGRET chooses the best margins depending on tinyPlot.
 #' @param col color of points on plot, see ?par 'Color Specification'
 #' @param lwd number line width
-#' @param prettyDate logical use 'pretty' limits for date axis if TRUE, or force the startYear/endYear as limits if FALSE
+#' @param randomCensored logical. Show censored values as randomized.
+#' @param prettyDate logical use 'pretty' limits for date axis if TRUE, or force the yearStart/yearEnd as limits if FALSE
 #' @param \dots arbitrary functions sent to the generic plotting function.  See ?par for details on possible parameters
 #' @keywords graphics water-quality statistics
 #' @export
@@ -34,20 +35,20 @@
 #' eList <- Choptank_eList
 #' # Water year:
 #' plotConcTimeDaily(eList)
-#' plotConcTimeDaily(eList, startYear=1998,endYear=2001)
+#' plotConcTimeDaily(eList, yearStart=1998,yearEnd=2001)
 #' # Graphs consisting of Jun-Aug
 #' eList <- setPA(eList, paStart=6,paLong=3)
 #' plotConcTimeDaily(eList)
-plotConcTimeDaily<-function(eList, startYear=NA, endYear=NA, tinyPlot = FALSE, 
-                            concMax = NA, printTitle = TRUE,cex=0.8, cex.axis=1.1,
+plotConcTimeDaily<-function(eList, yearStart=NA, yearEnd=NA, tinyPlot = FALSE, 
+                            concMax = NA, printTitle = TRUE,cex=0.8, cex.axis=1.1,randomCensored=FALSE,
                             cex.main=1.1, customPar=FALSE,col="black",lwd=1,prettyDate=TRUE,...){
 
   localINFO <- getInfo(eList)
   localSample <- getSample(eList)
   localDaily <- getDaily(eList)
   
-  startYear <- if (is.na(startYear)) as.integer(min(localSample$DecYear,na.rm=TRUE)) else startYear
-  endYear <- if (is.na(endYear)) as.integer(max(localSample$DecYear,na.rm=TRUE)) else endYear
+  yearStart <- if (is.na(yearStart)) as.integer(min(localSample$DecYear,na.rm=TRUE)) else yearStart
+  yearEnd <- if (is.na(yearEnd)) as.integer(max(localSample$DecYear,na.rm=TRUE)) else yearEnd
   
   if(sum(c("paStart","paLong") %in% names(localINFO)) == 2){
     paLong <- localINFO$paLong
@@ -62,39 +63,60 @@ plotConcTimeDaily<-function(eList, startYear=NA, endYear=NA, tinyPlot = FALSE,
   
   title2<-if(paLong==12) "" else setSeasonLabelByUser(paStartInput=paStart,paLongInput=paLong)
   
-  subSample<-localSample[localSample$DecYear>=startYear & localSample$DecYear<= endYear,]
-  subDaily<-localDaily[localDaily$DecYear>=startYear & localDaily$DecYear <= endYear,]
+  subSample<-localSample[localSample$DecYear>=yearStart & localSample$DecYear<= yearEnd,]
+  subDaily<-localDaily[localDaily$DecYear>=yearStart & localDaily$DecYear <= yearEnd,]
   
   xSample<-subSample$DecYear
   xDaily<-subDaily$DecYear
-
+  
   Uncen<-subSample$Uncen
-
+  
   plotTitle<-if(printTitle) paste(localINFO$shortName,"\n",localINFO$paramShortName,"\n","Observed and Estimated Concentration versus Time") else ""
   
   ###################################
   
   yBottom <- 0 #Not specified within script, added under assumption that it's always zero based on ylim definition in this function
   
-  xInfo <- generalAxis(x=xSample, minVal=startYear, maxVal=endYear, tinyPlot=tinyPlot,padPercent=0,prettyDate=prettyDate)  
+  xInfo <- generalAxis(x=xSample, minVal=yearStart, maxVal=yearEnd, tinyPlot=tinyPlot,padPercent=0,prettyDate=prettyDate)  
   
-  yLow<-subSample$ConcLow
-  yHigh<-subSample$ConcHigh
+  if(!randomCensored){
+    
+    yLow<-subSample$ConcLow
+    yHigh<-subSample$ConcHigh
+    
+    yCombined <- c(yHigh,subDaily$ConcDay)
+    yInfo <- generalAxis(x = yCombined, minVal = yBottom, maxVal = concMax, 
+                         tinyPlot = tinyPlot, padPercent = 5,units=localINFO$param.units)
+    
+    genericEGRETDotPlot(x=xSample, y=yHigh, xTicks=xInfo$ticks, yTicks=yInfo$ticks,
+                        xlim=c(xInfo$bottom,xInfo$top), ylim=c(yInfo$bottom,yInfo$top),
+                        ylab=yInfo$label,plotTitle=plotTitle,cex.axis=cex.axis,col=col,lwd=lwd,cex=cex,
+                        cex.main=cex.main, tinyPlot=tinyPlot,customPar=customPar, xDate=TRUE,...
+    )
+    
+    censoredSegments(yInfo$bottom,yLow=yLow,yHigh=yHigh,x=xSample,Uncen=Uncen,col=col,lwd=lwd)
+  } else {
+    if(!("rObserved" %in% names(localSample))){
+      eList <- makeAugmentedSample(eList)
+      localSample <- eList$Sample
+      subSample<-localSample[localSample$DecYear>=yearStart & localSample$DecYear<= yearEnd,]
+    }
+    
+    yHigh <- subSample$rObserved
+    
+    yCombined <- c(yHigh,subDaily$ConcDay)
+    yInfo <- generalAxis(x = yCombined, minVal = yBottom, maxVal = concMax, 
+                         tinyPlot = tinyPlot, padPercent = 5,units=localINFO$param.units)
+    genericEGRETDotPlot(x=xSample[subSample$Uncen == 1], y=yHigh[subSample$Uncen == 1], xTicks=xInfo$ticks, yTicks=yInfo$ticks,
+                        xlim=c(xInfo$bottom,xInfo$top), ylim=c(yInfo$bottom,yInfo$top),
+                        ylab=yInfo$label,plotTitle=plotTitle,cex.axis=cex.axis,col=col,lwd=lwd,cex=cex,
+                        cex.main=cex.main, tinyPlot=tinyPlot,customPar=customPar, xDate=TRUE,...
+    )
+    points(x=xSample[Uncen == 0], y=yHigh[Uncen == 0], pch=1,cex=cex,col=col)
+    
+  }
   
-  yCombined <- c(yHigh,subDaily$ConcDay)
-  yInfo <- generalAxis(x = yCombined, minVal = yBottom, maxVal = concMax, 
-                       tinyPlot = tinyPlot, padPercent = 5,units=localINFO$param.units)
-  
-  genericEGRETDotPlot(x=xSample, y=yHigh, xTicks=xInfo$ticks, yTicks=yInfo$ticks,
-                      xlim=c(xInfo$bottom,xInfo$top), ylim=c(yInfo$bottom,yInfo$top),
-                      ylab=yInfo$label,plotTitle=plotTitle,cex.axis=cex.axis,col=col,lwd=lwd,cex=cex,
-                      cex.main=cex.main, tinyPlot=tinyPlot,customPar=customPar, xDate=TRUE,...
-  )
-
-  censoredSegments(yInfo$bottom,yLow=yLow,yHigh=yHigh,x=xSample,Uncen=Uncen,col=col,lwd=lwd)
-
-
   lines(x=xDaily, y=subDaily$ConcDay, type="l",col=col,lwd=lwd)
   if (!tinyPlot) mtext(title2,side=3,line=-1.5)
-
+  
 }
\ No newline at end of file
