@@ -1,6 +1,7 @@
 #' Populate Concentration Columns
 #'
-#' Creates ConcLow, ConcHigh, Uncen (0 if censored, 1 if uncensored) columns for Sample data frame for WRTDS study.
+#' Creates ConcLow, ConcHigh, Uncen (0 if censored, 1 if uncensored) columns 
+#' for Sample data frame for WRTDS analysis.
 #'
 #' @param rawData vector with value and code columns
 #' @return concentrationColumns dataframe
@@ -14,9 +15,10 @@ populateConcentrations <- function(rawData){  # rawData is a dataframe with valu
   concentrationColumns <- as.data.frame(matrix(ncol=3,nrow=length(rawData$value)))
   colnames(concentrationColumns) <- c('ConcLow','ConcHigh','Uncen')  
   concentrationColumns$ConcLow <- as.numeric(ifelse((rawData$code!="<" | is.na(rawData$code)),rawData$value,0))
-  concentrationColumns$ConcHigh <- as.numeric(rawData$value)
+  concentrationColumns$ConcHigh <- as.numeric(ifelse((rawData$code != ">" | is.na(rawData$code)), rawData$value, 0))
   tempConcLow<-ifelse((rawData$code!="<" | is.na(rawData$code)),rawData$value,0)
-  concentrationColumns$Uncen <- ifelse(tempConcLow==0,0,1)  
+  tempConcHigh <- ifelse((rawData$code != ">" | is.na(rawData$code)), rawData$value, 0)
+  concentrationColumns$Uncen <- ifelse(tempConcLow == 0 | tempConcHigh == 0, 0, 1)
   #Add if value = NA?
   return (concentrationColumns)  # returns ConcLow, ConcHigh, Uncen (0 if censored, 1 if uncensored)
 }
