@@ -4,10 +4,12 @@
 #'
 #' @param rawData vector with dateTime
 #' @return DateFrame dataframe
-#' @importFrom lubridate decimal_date
 #' @export
+#' @rdname dateFuncs
 #' @examples
-#' dateTime <- c('1984-02-28 13:56', '1984-03-01', '1986-03-01',"1986-10-15")
+#' dateTime <- c('1984-02-28 13:56', '1984-03-01 00:00', '1986-03-01 00:00',"1986-10-15 00:00")
+#' expandedDateDF <- populateDateColumns(dateTime)
+#' dateTime <- c('1984-02-28', '1984-03-01', '1986-03-01',"1986-10-15")
 #' expandedDateDF <- populateDateColumns(dateTime)
 populateDateColumns <- function(rawData){  # rawData is a vector of dates
   DateFrame <- as.data.frame(matrix(ncol=1,nrow=length(rawData)))
@@ -29,7 +31,7 @@ populateDateColumns <- function(rawData){  # rawData is a vector of dates
   
   DateFrame$Day[DateFrame$Day > 59] <- DateFrame$Day[DateFrame$Day > 59] + leapOffset[DateFrame$Day > 59]
 
-  DateFrame$DecYear <- decimal_date(dateTime)
+  DateFrame$DecYear <- decimalDate(dateTime)
   DateFrame$MonthSeq <- ((year-1850)*12)+DateFrame$Month
   DateFrame$waterYear <- as.integer(DateFrame$DecYear)
   DateFrame$waterYear[DateFrame$Month %in% c(10:12)] <- DateFrame$waterYear[DateFrame$Month %in% c(10:12)]+1
@@ -37,3 +39,21 @@ populateDateColumns <- function(rawData){  # rawData is a vector of dates
   return (DateFrame)
   
 }
+
+#' @export
+#' @rdname dateFuncs
+#' 
+#' @examples 
+#' dateTime <- c('1984-02-28 13:56', '1984-03-01 00:00', '1986-03-01 00:00',"1986-10-15 00:00")
+#' decimalDate(dateTime)
+decimalDate <- function(rawData){
+  
+  dateTime <- as.POSIXlt(rawData)
+  year <- dateTime$year + 1900
+  
+  startYear <- as.POSIXct(paste0(year,"-01-01 00:00"))
+  endYear <- as.POSIXct(paste0(year+1,"-01-01 00:00"))
+  
+  DecYear <- year + as.numeric(difftime(dateTime, startYear, units = "secs"))/as.numeric(difftime(endYear, startYear, units = "secs"))
+  return(DecYear)
+}
