@@ -1,9 +1,10 @@
 #' Populate Sample Columns
 #'
-#' Creates ConcAve and ConcLow based on Uncen. Removes any samples with NA values in ConcHigh
+#' Creates ConcAve and ConcLow based on Uncen. Removes any samples with NA values in ConcHigh.
 #'
 #' @param rawData dataframe with dateTime, ConcLow, ConcHigh, Uncen
-#' @return Sample2 dataframe
+#' @return Sample2 dataframe with columns: Date, ConcLow, ConcHigh, Uncen, ConcAve, Julian, 
+#' Month, Day, DecYear, MonthSeq, waterYear, SinDY, and CosDY (DY = decimal year)
 #' @export
 #' @examples
 #' dateTime <- c('1985-01-01', '1985-01-02', '1985-01-03')
@@ -19,14 +20,15 @@ populateSampleColumns <- function(rawData){  # rawData is a dataframe with dateT
   Sample$ConcLow <- rawData$ConcLow
   Sample$ConcHigh <- rawData$ConcHigh
   Sample$Uncen <- rawData$Uncen
-  Sample$ConcAve <- (Sample$ConcLow+Sample$ConcHigh)/2
+  Sample$ConcAve <- ifelse(Sample$ConcHigh == 0, Sample$ConcLow*1.5, (Sample$ConcLow + Sample$ConcHigh)/2)
   Sample$ConcLow <- ifelse((rawData$ConcLow == 0.0 & rawData$Uncen == 0),NA,rawData$ConcLow)
+  Sample$ConcHigh <- ifelse((rawData$ConcHigh == 0 & rawData$Uncen == 0), NA, rawData$ConcHigh)
   
   dateFrame <- populateDateColumns(rawData$dateTime)
   Sample <- cbind(Sample, dateFrame[,-1])
   
   Sample$SinDY <- sin(2*pi*Sample$DecYear)
   Sample$CosDY <- cos(2*pi*Sample$DecYear)
-  Sample2 <- subset(Sample, (!is.na(Sample$ConcHigh)))  # Was just ConcHigh.....
-  return (Sample2)  
+  # Sample2 <- subset(Sample, (!is.na(Sample$ConcHigh)))  # Was just ConcHigh.....
+  return (Sample)  
 }
