@@ -1,7 +1,7 @@
 #' Import NWIS Sample Data for EGRET analysis
 #'
-#' Imports data from NWIS web service. This function gets the data from here: \url{http://nwis.waterdata.usgs.gov/nwis/qwdata/}
-#' A list of parameter and statistic codes can be found here: \url{http://help.waterdata.usgs.gov/codes-and-parameters}
+#' Imports data from NWIS web service. This function gets the data from here: \url{https://nwis.waterdata.usgs.gov/nwis/qwdata/}
+#' A list of parameter and statistic codes can be found here: \url{https://help.waterdata.usgs.gov/codes-and-parameters}
 #' For raw data, use \code{\link[dataRetrieval]{readNWISqw}} from the dataRetrieval package.  This function will retrieve the raw data, and compress it (summing constituents). See
 #' section 3.2.4 of the vignette for more details.
 #'
@@ -9,9 +9,9 @@
 #' @param parameterCd character USGS parameter code.  This is usually an 5 digit number.
 #' @param startDate character starting date for data retrieval in the form YYYY-MM-DD.
 #' @param endDate character ending date for data retrieval in the form YYYY-MM-DD.
-#' @param interactive logical Option for interactive mode.  If true, there is user interaction for error handling and data checks.
+#' @param verbose logical specifying whether or not to display progress message
+#' @param interactive logical deprecated. Use 'verbose' instead
 #' @keywords data import USGS WRTDS
-#' @import dataRetrieval
 #' @export
 #' @return A data frame 'Sample' with the following columns:
 #' \tabular{lll}{
@@ -36,10 +36,13 @@
 #' # These examples require an internet connection to run
 #' 
 #' Sample_01075 <- readNWISSample('01594440','01075', '1985-01-01', '1985-03-31')
-#' Sample_All2 <- readNWISSample('05114000',c('00915','00931'), '1985-01-01', '1985-03-31')
-#' Sample_Select <- readNWISSample('05114000',c('00915','00931'), '', '')
 #' }
-readNWISSample <- function(siteNumber,parameterCd,startDate="",endDate="",interactive=TRUE){
+readNWISSample <- function(siteNumber,parameterCd,startDate="",endDate="",verbose = TRUE,interactive=NULL){
+  
+  if(!is.null(interactive)) {
+    warning("The argument 'interactive' is deprecated. Please use 'verbose' instead")
+    verbose <- interactive
+  }
   
   rawSample <- dataRetrieval::readNWISqw(siteNumber,parameterCd,startDate,endDate, expanded=FALSE)
   if(nrow(rawSample) > 0){
@@ -47,7 +50,7 @@ readNWISSample <- function(siteNumber,parameterCd,startDate="",endDate="",intera
     remarkColumns <- grep("r\\d{5}",names(rawSample))
     totalColumns <-c(grep("sample_dt",names(rawSample)), dataColumns, remarkColumns)
     totalColumns <- totalColumns[order(totalColumns)]
-    compressedData <- compressData(rawSample[,totalColumns], interactive=interactive)
+    compressedData <- compressData(rawSample[,totalColumns], verbose=verbose)
     Sample <- populateSampleColumns(compressedData)
   } else {
     Sample <- data.frame(Date=as.Date(character()),
