@@ -7,7 +7,8 @@
 #' @param hasHeader logical true if the first row of data is the column headers
 #' @param separator character character that separates data cells
 #' @param qUnit number 1 is cubic feet per second, 2 is cubic meters per second, 3 is 10^3 cubic feet per second, and 4 is 10^3 cubic meters per second
-#' @param interactive logical Option for interactive mode.  If true, there is user interaction for error handling and data checks.
+#' @param verbose logical specifying whether or not to display progress message
+#' @param interactive logical deprecated. Use 'verbose' instead
 #' @keywords data import file
 #' @keywords data import USGS WRTDS
 #' @export
@@ -31,15 +32,21 @@
 #' filePath <- system.file("extdata", package="EGRET")
 #' fileName <- "ChoptankRiverFlow.txt"
 #' Daily <- readUserDaily(filePath,fileName,separator="\t")
-readUserDaily <- function (filePath,fileName,hasHeader=TRUE,separator=",",qUnit=1,interactive=TRUE){
+readUserDaily <- function (filePath,fileName,hasHeader=TRUE,separator=",",qUnit=1,verbose = TRUE,interactive=NULL){
+  
+  if(!is.null(interactive)) {
+    warning("The argument 'interactive' is deprecated. Please use 'verbose' instead")
+    verbose <- interactive
+  }
+  
   data <- readDataFromFile(filePath,fileName,hasHeader=hasHeader,separator=separator)
   convertQ<-c(35.314667,1,0.035314667,0.001)
   qConvert<-convertQ[qUnit]
-  if (interactive){
-    if(qUnit==1) cat("\n the input discharge are assumed to be in cubic feet per second\nif they are in cubic meters per second, then the call to readUserDaily should specify qUnit=2\n")
-  }
+
+  if(qUnit==1) message("The input discharge are assumed to be in cubic feet per second, if they are in cubic meters per second, then the call to readUserDaily should specify qUnit=2")
+
   names(data) <- c("dateTime", "value")
-  localDaily <- populateDaily(data,qConvert, interactive=interactive)
+  localDaily <- populateDaily(data,qConvert, verbose=verbose)
   localDaily <- localDaily[!is.na(localDaily$Q),]
   return(localDaily)
 }
